@@ -1,9 +1,12 @@
+require 'puppet/concurrent/thread_local_singleton'
+
 module Puppet::Pops
 module Parser
 
 # Does not support "import" and parsing ruby files
 #
 class EvaluatingParser
+  extend Puppet::Concurrent::ThreadLocalSingleton
 
   attr_reader :parser
 
@@ -11,10 +14,6 @@ class EvaluatingParser
     @parser = Parser.new()
   end
 
-  def self.singleton
-    @instance ||= new
-  end
-
   def parse_string(s, file_source = nil)
     @file_source = file_source
     clear()
@@ -80,7 +79,7 @@ class EvaluatingParser
   end
 
   def convert_to_3x(object, scope)
-    val = evaluator.convert(object, scope, nil)
+    evaluator.convert(object, scope, nil)
   end
 
   def validate(parse_result)
